package #
Date::Manip::Offset::off051;
# Copyright (c) 2008-2020 Sullivan Beck.  All rights reserved.
# This program is free software; you can redistribute it and/or modify it
# under the same terms as Perl itself.

# This file was automatically generated.  Any changes to this file will
# be lost the next time 'tzdata' is run.
#    Generated on: Mon Nov 30 13:52:44 EST 2020
#    Data version: tzdata2020d
#    Code version: tzcode2020d

# This module contains data from the zoneinfo time zone database.  The original
# data was obtained from the URL:
#    ftp://ftp.iana.org/tz

use strict;
use warnings;
require 5.010000;

our ($VERSION);
$VERSION='6.83';
END { undef $VERSION; }

our ($Offset,%Offset);
END {
   undef $Offset;
   undef %Offset;
}

$Offset        = '+02:00:00';

%Offset        = (
   0 => [
      'eet',
      'asia/beirut',
      'europe/sofia',
      'asia/gaza',
      'asia/hebron',
      'africa/cairo',
      'africa/johannesburg',
      'africa/maputo',
      'africa/windhoek',
      'europe/athens',
      'asia/jerusalem',
      'asia/damascus',
      'europe/vilnius',
      'europe/helsinki',
      'europe/tallinn',
      'asia/famagusta',
      'asia/nicosia',
      'europe/kiev',
      'europe/zaporozhye',
      'europe/riga',
      'asia/amman',
      'africa/khartoum',
      'europe/bucharest',
      'europe/chisinau',
      'europe/kaliningrad',
      'africa/tripoli',
      'europe/uzhgorod',
      'etc/gmt+2',
      'o',
      'europe/istanbul',
      'europe/simferopol',
      'europe/minsk',
      'africa/juba',
      'europe/moscow',
      'europe/ulyanovsk',
      'europe/warsaw',
      ],
   1 => [
      'cet',
      'europe/berlin',
      'europe/brussels',
      'europe/budapest',
      'europe/copenhagen',
      'europe/luxembourg',
      'europe/malta',
      'europe/oslo',
      'europe/prague',
      'europe/rome',
      'europe/stockholm',
      'europe/vienna',
      'europe/warsaw',
      'met',
      'europe/madrid',
      'europe/amsterdam',
      'europe/paris',
      'europe/tirane',
      'europe/belgrade',
      'europe/gibraltar',
      'europe/monaco',
      'europe/zurich',
      'europe/andorra',
      'africa/ceuta',
      'antarctica/troll',
      'africa/tripoli',
      'africa/tunis',
      'europe/vilnius',
      'europe/lisbon',
      'africa/ndjamena',
      'africa/algiers',
      'europe/london',
      'europe/kaliningrad',
      'europe/tallinn',
      'europe/uzhgorod',
      'europe/chisinau',
      'europe/minsk',
      'europe/riga',
      'europe/simferopol',
      'europe/sofia',
      'europe/athens',
      'europe/kiev',
      'europe/zaporozhye',
      ],
);

1;
